EXPORTS
	??0RSsmStateAwareSession@@QAE@XZ @ 1 NONAME ; RSsmStateAwareSession::RSsmStateAwareSession(void)
	??0TSsmState@@QAE@ABV0@@Z @ 2 NONAME ; TSsmState::TSsmState(class TSsmState const &)
	??0TSsmState@@QAE@GG@Z @ 3 NONAME ; TSsmState::TSsmState(unsigned short, unsigned short)
	??0TSsmState@@QAE@W4TSsmMainSystemStates@@G@Z @ 4 NONAME ; TSsmState::TSsmState(enum TSsmMainSystemStates, unsigned short)
	??0TSsmState@@QAE@XZ @ 5 NONAME ; TSsmState::TSsmState(void)
	??0TSsmStateTransition@@QAE@ABV0@@Z @ 6 NONAME ; TSsmStateTransition::TSsmStateTransition(class TSsmStateTransition const &)
	??0TSsmStateTransition@@QAE@GGH@Z @ 7 NONAME ; TSsmStateTransition::TSsmStateTransition(unsigned short, unsigned short, int)
	??0TSsmStateTransition@@QAE@VTSsmState@@H@Z @ 8 NONAME ; TSsmStateTransition::TSsmStateTransition(class TSsmState, int)
	??0TSsmStateTransition@@QAE@XZ @ 9 NONAME ; TSsmStateTransition::TSsmStateTransition(void)
	??0TSsmSwp@@QAE@ABV0@@Z @ 10 NONAME ; TSsmSwp::TSsmSwp(class TSsmSwp const &)
	??0TSsmSwp@@QAE@IJ@Z @ 11 NONAME ; TSsmSwp::TSsmSwp(unsigned int, long)
	??1CSsmStartupProperties@@UAE@XZ @ 12 NONAME ; CSsmStartupProperties::~CSsmStartupProperties(void)
	??1CSsmStateAwareSession@@UAE@XZ @ 13 NONAME ; CSsmStateAwareSession::~CSsmStateAwareSession(void)
	??1CSsmSystemWideProperty@@UAE@XZ @ 14 NONAME ; CSsmSystemWideProperty::~CSsmSystemWideProperty(void)
	??1RSsmStateAwareSession@@QAE@XZ @ 15 NONAME ABSENT ; RSsmStateAwareSession::~RSsmStateAwareSession(void)
	??4TSsmState@@QAEAAV0@ABV0@@Z @ 16 NONAME ; class TSsmState & TSsmState::operator=(class TSsmState const &)
	??4TSsmStateTransition@@QAEAAV0@ABV0@@Z @ 17 NONAME ; class TSsmStateTransition & TSsmStateTransition::operator=(class TSsmStateTransition const &)
	??4TSsmSwp@@QAEAAV0@ABV0@@Z @ 18 NONAME ; class TSsmSwp & TSsmSwp::operator=(class TSsmSwp const &)
	??8TSsmState@@QBEHABV0@@Z @ 19 NONAME ; int TSsmState::operator==(class TSsmState const &) const
	??8TSsmStateTransition@@QBEHABV0@@Z @ 20 NONAME ; int TSsmStateTransition::operator==(class TSsmStateTransition const &) const
	??8TSsmSwp@@QBEHABV0@@Z @ 21 NONAME ; int TSsmSwp::operator==(class TSsmSwp const &) const
	??9TSsmState@@QBEHABV0@@Z @ 22 NONAME ; int TSsmState::operator!=(class TSsmState const &) const
	??9TSsmStateTransition@@QBEHABV0@@Z @ 23 NONAME ; int TSsmStateTransition::operator!=(class TSsmStateTransition const &) const
	??9TSsmSwp@@QBEHABV0@@Z @ 24 NONAME ; int TSsmSwp::operator!=(class TSsmSwp const &) const
	?AcknowledgeAndRequestStateNotification@RSsmStateAwareSession@@QAEXHAAVTRequestStatus@@@Z @ 25 NONAME ; void RSsmStateAwareSession::AcknowledgeAndRequestStateNotification(int, class TRequestStatus &)
	?AcknowledgeStateNotification@RSsmStateAwareSession@@QAEXH@Z @ 26 NONAME ; void RSsmStateAwareSession::AcknowledgeStateNotification(int)
	?AddSubscriberL@CSsmStateAwareSession@@QAEXAAVMStateChangeNotificationSubscriber@@@Z @ 27 NONAME ; void CSsmStateAwareSession::AddSubscriberL(class MStateChangeNotificationSubscriber &)
	?AddSubscriberL@CSsmSystemWideProperty@@QAEXAAVMSwpChangeNotificationSubscriber@@@Z @ 28 NONAME ; void CSsmSystemWideProperty::AddSubscriberL(class MSwpChangeNotificationSubscriber &)
	?Args@CSsmStartupProperties@@QBE?AVTPtrC16@@XZ @ 29 NONAME ; class TPtrC16 CSsmStartupProperties::Args(void) const
	?Close@RSsmStateAwareSession@@QAEXXZ @ 30 NONAME ; void RSsmStateAwareSession::Close(void)
	?Close@RSsmStateManager@@QAEXXZ @ 31 NONAME ; void RSsmStateManager::Close(void)
	?Close@RSsmSystemWideProperty@@QAEXXZ @ 32 NONAME ; void RSsmSystemWideProperty::Close(void)
	?CommandType@CSsmStartupProperties@@QBE?AW4TSsmCommandType@@XZ @ 33 NONAME ; enum TSsmCommandType CSsmStartupProperties::CommandType(void) const
	?Connect@RSsmStateAwareSession@@QAEHG@Z @ 34 NONAME ; int RSsmStateAwareSession::Connect(unsigned short)
	?Connect@RSsmStateManager@@QAEHH@Z @ 35 NONAME ; int RSsmStateManager::Connect(int)
	?Connect@RSsmStateManager@@QAEHXZ @ 36 NONAME ; int RSsmStateManager::Connect(void)
	?Connect@RSsmSystemWideProperty@@QAEHI@Z @ 37 NONAME ; int RSsmSystemWideProperty::Connect(unsigned int)
	?ExecutionBehaviour@CSsmStartupProperties@@QBE?AW4TSsmExecutionBehaviour@@XZ @ 38 NONAME ; enum TSsmExecutionBehaviour CSsmStartupProperties::ExecutionBehaviour(void) const
	?ExternalizeL@CSsmStartupProperties@@QBEXAAVRWriteStream@@@Z @ 39 NONAME ; void CSsmStartupProperties::ExternalizeL(class RWriteStream &) const
	?FileName@CSsmStartupProperties@@QBE?AVTPtrC16@@XZ @ 40 NONAME ; class TPtrC16 CSsmStartupProperties::FileName(void) const
	?GetValue@CSsmSystemWideProperty@@QBEHAAVTSsmSwp@@@Z @ 41 NONAME ; int CSsmSystemWideProperty::GetValue(class TSsmSwp &) const
	?GetValue@RSsmSystemWideProperty@@QBEHAAH@Z @ 42 NONAME ; int RSsmSystemWideProperty::GetValue(int &) const
	?Int@TSsmState@@QBEKXZ @ 43 NONAME ; unsigned long TSsmState::Int(void) const
	?InternalizeL@CSsmStartupProperties@@QAEXAAVRReadStream@@@Z @ 44 NONAME ; void CSsmStartupProperties::InternalizeL(class RReadStream &)
	?IsMonitoringRequired@CSsmStartupProperties@@QBEHXZ @ 45 NONAME ; int CSsmStartupProperties::IsMonitoringRequired(void) const
	?Key@TSsmSwp@@QBEIXZ @ 46 NONAME ; unsigned int TSsmSwp::Key(void) const
	?MainState@TSsmState@@QBEGXZ @ 47 NONAME ; unsigned short TSsmState::MainState(void) const
	?MonitorInfo@CSsmStartupProperties@@QBE?AUTSsmMonitorInfo@@XZ @ 48 NONAME ; struct TSsmMonitorInfo CSsmStartupProperties::MonitorInfo(void) const
	?Name@TSsmState@@QBE?AV?$TBuf@$0L@@@XZ @ 49 NONAME ; class TBuf<11> TSsmState::Name(void) const
	?NewL@CSsmStartupProperties@@SAPAV1@AAVRResourceReader@@PAVCResourceFile@@W4TSsmCommandType@@@Z @ 50 NONAME ; class CSsmStartupProperties * CSsmStartupProperties::NewL(class RResourceReader &, class CResourceFile *, enum TSsmCommandType)
	?NewL@CSsmStartupProperties@@SAPAV1@ABV1@@Z @ 51 NONAME ; class CSsmStartupProperties * CSsmStartupProperties::NewL(class CSsmStartupProperties const &)
	?NewL@CSsmStartupProperties@@SAPAV1@ABVTDesC16@@0@Z @ 52 NONAME ; class CSsmStartupProperties * CSsmStartupProperties::NewL(class TDesC16 const &, class TDesC16 const &)
	?NewL@CSsmStartupProperties@@SAPAV1@XZ @ 53 NONAME ; class CSsmStartupProperties * CSsmStartupProperties::NewL(void)
	?NewL@CSsmStateAwareSession@@SAPAV1@G@Z @ 54 NONAME ; class CSsmStateAwareSession * CSsmStateAwareSession::NewL(unsigned short)
	?NewL@CSsmSystemWideProperty@@SAPAV1@I@Z @ 55 NONAME ; class CSsmSystemWideProperty * CSsmSystemWideProperty::NewL(unsigned int)
	?NewLC@CSsmStartupProperties@@SAPAV1@AAVRResourceReader@@PAVCResourceFile@@W4TSsmCommandType@@@Z @ 56 NONAME ; class CSsmStartupProperties * CSsmStartupProperties::NewLC(class RResourceReader &, class CResourceFile *, enum TSsmCommandType)
	?NewLC@CSsmStartupProperties@@SAPAV1@ABVTDesC16@@0@Z @ 57 NONAME ; class CSsmStartupProperties * CSsmStartupProperties::NewLC(class TDesC16 const &, class TDesC16 const &)
	?NewLC@CSsmStartupProperties@@SAPAV1@XZ @ 58 NONAME ; class CSsmStartupProperties * CSsmStartupProperties::NewLC(void)
	?NewLC@CSsmStateAwareSession@@SAPAV1@G@Z @ 59 NONAME ; class CSsmStateAwareSession * CSsmStateAwareSession::NewLC(unsigned short)
	?NewLC@CSsmSystemWideProperty@@SAPAV1@I@Z @ 60 NONAME ; class CSsmSystemWideProperty * CSsmSystemWideProperty::NewLC(unsigned int)
	?Reason@TSsmStateTransition@@QBEHXZ @ 61 NONAME ; int TSsmStateTransition::Reason(void) const
	?RegisterSwpMapping@RSsmStateManager@@QAEHIABVTDesC16@@@Z @ 62 NONAME ; int RSsmStateManager::RegisterSwpMapping(unsigned int, class TDesC16 const &)
	?RemoveSubscriber@CSsmStateAwareSession@@QAEXABVMStateChangeNotificationSubscriber@@@Z @ 63 NONAME ; void CSsmStateAwareSession::RemoveSubscriber(class MStateChangeNotificationSubscriber const &)
	?RemoveSubscriber@CSsmSystemWideProperty@@QAEXABVMSwpChangeNotificationSubscriber@@@Z @ 64 NONAME ; void CSsmSystemWideProperty::RemoveSubscriber(class MSwpChangeNotificationSubscriber const &)
	?RequestStateNotification@RSsmStateAwareSession@@QAEXAAVTRequestStatus@@@Z @ 65 NONAME ; void RSsmStateAwareSession::RequestStateNotification(class TRequestStatus &)
	?RequestStateNotificationCancel@RSsmStateAwareSession@@QAEXXZ @ 66 NONAME ; void RSsmStateAwareSession::RequestStateNotificationCancel(void)
	?RequestStateTransition@RSsmStateManager@@QAEHVTSsmStateTransition@@@Z @ 67 NONAME ; int RSsmStateManager::RequestStateTransition(class TSsmStateTransition)
	?RequestStateTransition@RSsmStateManager@@QAEXVTSsmStateTransition@@AAVTRequestStatus@@@Z @ 68 NONAME ; void RSsmStateManager::RequestStateTransition(class TSsmStateTransition, class TRequestStatus &)
	?RequestStateTransitionCancel@RSsmStateManager@@QAEXXZ @ 69 NONAME ; void RSsmStateManager::RequestStateTransitionCancel(void)
	?RequestSwpChange@RSsmStateManager@@QAEHVTSsmSwp@@@Z @ 70 NONAME ; int RSsmStateManager::RequestSwpChange(class TSsmSwp)
	?RequestSwpChange@RSsmStateManager@@QAEXVTSsmSwp@@AAVTRequestStatus@@@Z @ 71 NONAME ; void RSsmStateManager::RequestSwpChange(class TSsmSwp, class TRequestStatus &)
	?RequestSwpChangeCancel@RSsmStateManager@@QAEXXZ @ 72 NONAME ; void RSsmStateManager::RequestSwpChangeCancel(void)
	?Reset@CSsmStartupProperties@@QAEXXZ @ 73 NONAME ; void CSsmStartupProperties::Reset(void)
	?Retries@CSsmStartupProperties@@QBEHXZ @ 74 NONAME ; int CSsmStartupProperties::Retries(void) const
	?Set@TSsmState@@QAEXGG@Z @ 75 NONAME ; void TSsmState::Set(unsigned short, unsigned short)
	?Set@TSsmSwp@@QAEXIJ@Z @ 76 NONAME ; void TSsmSwp::Set(unsigned int, long)
	?SetCommandTypeL@CSsmStartupProperties@@QAEXW4TSsmCommandType@@@Z @ 77 NONAME ; void CSsmStartupProperties::SetCommandTypeL(enum TSsmCommandType)
	?SetExecutionBehaviour@CSsmStartupProperties@@QAEXW4TSsmExecutionBehaviour@@@Z @ 78 NONAME ; void CSsmStartupProperties::SetExecutionBehaviour(enum TSsmExecutionBehaviour)
	?SetFileParamsL@CSsmStartupProperties@@QAEXABVTDesC16@@0@Z @ 79 NONAME ; void CSsmStartupProperties::SetFileParamsL(class TDesC16 const &, class TDesC16 const &)
	?SetFromInt@TSsmState@@QAEXK@Z @ 80 NONAME ; void TSsmState::SetFromInt(unsigned long)
	?SetMonitorInfoL@CSsmStartupProperties@@QAEXUTSsmMonitorInfo@@@Z @ 81 NONAME ; void CSsmStartupProperties::SetMonitorInfoL(struct TSsmMonitorInfo)
	?SetRetries@CSsmStartupProperties@@QAEXH@Z @ 82 NONAME ; void CSsmStartupProperties::SetRetries(int)
	?SetStartInBackground@CSsmStartupProperties@@QAEXH@Z @ 83 NONAME ; void CSsmStartupProperties::SetStartInBackground(int)
	?SetTimeout@CSsmStartupProperties@@QAEXJ@Z @ 84 NONAME ; void CSsmStartupProperties::SetTimeout(long)
	?SetViewless@CSsmStartupProperties@@QAEXH@Z @ 85 NONAME ; void CSsmStartupProperties::SetViewless(int)
	?StartInBackground@CSsmStartupProperties@@QBEHXZ @ 86 NONAME ; int CSsmStartupProperties::StartInBackground(void) const
	?State@CSsmStateAwareSession@@QBE?AVTSsmState@@XZ @ 87 NONAME ; class TSsmState CSsmStateAwareSession::State(void) const
	?State@RSsmStateAwareSession@@QBE?AVTSsmState@@XZ @ 88 NONAME ; class TSsmState RSsmStateAwareSession::State(void) const
	?State@TSsmStateTransition@@QBE?AVTSsmState@@XZ @ 89 NONAME ; class TSsmState TSsmStateTransition::State(void) const
	?SubState@TSsmState@@QBEGXZ @ 90 NONAME ; unsigned short TSsmState::SubState(void) const
	?Subscribe@RSsmSystemWideProperty@@QAEXAAVTRequestStatus@@@Z @ 91 NONAME ; void RSsmSystemWideProperty::Subscribe(class TRequestStatus &)
	?SubscribeCancel@RSsmSystemWideProperty@@QAEXXZ @ 92 NONAME ; void RSsmSystemWideProperty::SubscribeCancel(void)
	?Timeout@CSsmStartupProperties@@QBEJXZ @ 93 NONAME ; long CSsmStartupProperties::Timeout(void) const
	?Value@TSsmSwp@@QBEJXZ @ 94 NONAME ; long TSsmSwp::Value(void) const
	?Viewless@CSsmStartupProperties@@QBEHXZ @ 95 NONAME ; int CSsmStartupProperties::Viewless(void) const	
	?A @ 96 NONAME ABSENT ; unsigned long const KSsmGracefulShutdown
	?B @ 97 NONAME ABSENT ; unsigned long IsSsmGracefulShutdown(void)
	?IsSsmGracefulOffline@@YAKXZ @ 98 NONAME ; unsigned long IsSsmGracefulOffline(void)
	?KSsmGracefulOffline@@3KB @ 99 NONAME ; unsigned long const KSsmGracefulOffline
	?KSsmInvalidSim@@3KB @ 100 NONAME ; unsigned long const KSsmInvalidSim

